==> aws-cdk.aws-rds-1.75.0.tar.gz: package/lib/option-group.d.ts <==
import * as ec2 from '@aws-cdk/aws-ec2';
import { IResource, Resource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { IInstanceEngine } from './instance-engine';
/**
 * An option group.
 */
export interface IOptionGroup extends IResource {
    /**
     * The name of the option group.
     *
     * @attribute true
     */
    readonly optionGroupName: string;
    /**
     * Adds a configuration to this OptionGroup.
     *
     * This method is a no-op for an imported OptionGroup.
     *
     * @returns true if the OptionConfiguration was successfully added.
     */
    addConfiguration(configuration: OptionConfiguration): boolean;
}
/**
 * Configuration properties for an option.
 */
export interface OptionConfiguration {
    /**
     * The name of the option.
     */
    readonly name: string;
    /**
     * The settings for the option.
     *
     * @default - no settings
     */
    readonly settings?: {
        [name: string]: string;
    };
    /**
     * The version for the option.
     *
     * @default - no version
     */
    readonly version?: string;
    /**
     * The port number that this option uses.
     *
     * If `port` is specified then `vpc`
     * must also be specified.
     *
     * @default - no port
     */
    readonly port?: number;
    /**
     * The VPC where a security group should be created for this option.
     *
     * If `vpc`
     * is specified then `port` must also be specified.
     *
     * @default - no VPC
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Optional list of security groups to use for this option, if `vpc` is specified.
     *
     * If no groups are provided, a default one will be created.
     *
     * @default - a default group will be created if `port` or `vpc` are specified.
     */
    readonly securityGroups?: ec2.ISecurityGroup[];
}
/**
 * Construction properties for an OptionGroup.
 */
export interface OptionGroupProps {
    /**
     * The database engine that this option group is associated with.
     */
    readonly engine: IInstanceEngine;
    /**
     * A description of the option group.
     *
     * @default a CDK generated description
     */
    readonly description?: string;
    /**
     * The configurations for this option group.
     */
    readonly configurations: OptionConfiguration[];
}
/**
 * An option group.
 */
export declare class OptionGroup extends Resource implements IOptionGroup {
    /**
     * Import an existing option group.
     */
    static fromOptionGroupName(scope: Construct, id: string, optionGroupName: string): IOptionGroup;
    /**
     * The name of the option group.
     */
    readonly optionGroupName: string;
    /**
     * The connections object for the options.
     */
    readonly optionConnections: {
        [key: string]: ec2.Connections;
    };
    private readonly configurations;
    /**
     *
     */
    constructor(scope: Construct, id: string, props: OptionGroupProps);
    /**
     * Adds a configuration to this OptionGroup.
     *
     * This method is a no-op for an imported OptionGroup.
     */
    addConfiguration(configuration: OptionConfiguration): boolean;
    /**
     * Renders the option configurations specifications.
     */
    private renderConfigurations;
}

==> aws-cdk.aws-rds-1.98.0.tar.gz: package/lib/option-group.d.ts <==
import * as ec2 from '@aws-cdk/aws-ec2';
import { IResource, Resource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { IInstanceEngine } from './instance-engine';
/**
 * An option group.
 *
 * @stability stable
 */
export interface IOptionGroup extends IResource {
    /**
     * The name of the option group.
     *
     * @stability stable
     * @attribute true
     */
    readonly optionGroupName: string;
    /**
     * Adds a configuration to this OptionGroup.
     *
     * This method is a no-op for an imported OptionGroup.
     *
     * @returns true if the OptionConfiguration was successfully added.
     * @stability stable
     */
    addConfiguration(configuration: OptionConfiguration): boolean;
}
/**
 * Configuration properties for an option.
 *
 * @stability stable
 */
export interface OptionConfiguration {
    /**
     * The name of the option.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The settings for the option.
     *
     * @default - no settings
     * @stability stable
     */
    readonly settings?: {
        [name: string]: string;
    };
    /**
     * The version for the option.
     *
     * @default - no version
     * @stability stable
     */
    readonly version?: string;
    /**
     * The port number that this option uses.
     *
     * If `port` is specified then `vpc`
     * must also be specified.
     *
     * @default - no port
     * @stability stable
     */
    readonly port?: number;
    /**
     * The VPC where a security group should be created for this option.
     *
     * If `vpc`
     * is specified then `port` must also be specified.
     *
     * @default - no VPC
     * @stability stable
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Optional list of security groups to use for this option, if `vpc` is specified.
     *
     * If no groups are provided, a default one will be created.
     *
     * @default - a default group will be created if `port` or `vpc` are specified.
     * @stability stable
     */
    readonly securityGroups?: ec2.ISecurityGroup[];
}
/**
 * Construction properties for an OptionGroup.
 *
 * @stability stable
 */
export interface OptionGroupProps {
    /**
     * The database engine that this option group is associated with.
     *
     * @stability stable
     */
    readonly engine: IInstanceEngine;
    /**
     * A description of the option group.
     *
     * @default a CDK generated description
     * @stability stable
     */
    readonly description?: string;
    /**
     * The configurations for this option group.
     *
     * @stability stable
     */
    readonly configurations: OptionConfiguration[];
}
/**
 * An option group.
 *
 * @stability stable
 */
export declare class OptionGroup extends Resource implements IOptionGroup {
    /**
     * Import an existing option group.
     *
     * @stability stable
     */
    static fromOptionGroupName(scope: Construct, id: string, optionGroupName: string): IOptionGroup;
    /**
     * The name of the option group.
     *
     * @stability stable
     */
    readonly optionGroupName: string;
    /**
     * The connections object for the options.
     *
     * @stability stable
     */
    readonly optionConnections: {
        [key: string]: ec2.Connections;
    };
    private readonly configurations;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: OptionGroupProps);
    /**
     * Adds a configuration to this OptionGroup.
     *
     * This method is a no-op for an imported OptionGroup.
     *
     * @stability stable
     */
    addConfiguration(configuration: OptionConfiguration): boolean;
    /**
     * Renders the option configurations specifications.
     */
    private renderConfigurations;
}
